import { Instruction } from "@orca-so/common-sdk";
import { Program } from "@project-serum/anchor";
import { PublicKey } from "@solana/web3.js";
import { Whirlpool } from "../artifacts/whirlpool";
import { TwoHopSwapParams } from "./two-hop-swap-ix";
/**
 * Parameters to execute a two-hop swap on a Whirlpool.
 *
 * @category Instruction Types
 * @param whirlpoolOne - PublicKey for the whirlpool that the swap-one will occur on
 * @param whirlpoolTwo - PublicKey for the whirlpool that the swap-two will occur on
 * @param tokenOwnerAccountOneA - PublicKey for the associated token account for tokenA in whirlpoolOne in the collection wallet
 * @param tokenOwnerAccountOneB - PublicKey for the associated token account for tokenB in whirlpoolOne in the collection wallet
 * @param tokenOwnerAccountTwoA - PublicKey for the associated token account for tokenA in whirlpoolTwo in the collection wallet
 * @param tokenOwnerAccountTwoB - PublicKey for the associated token account for tokenB in whirlpoolTwo in the collection wallet
 * @param tokenVaultOneA - PublicKey for the tokenA vault for whirlpoolOne.
 * @param tokenVaultOneB - PublicKey for the tokenB vault for whirlpoolOne.
 * @param tokenVaultTwoA - PublicKey for the tokenA vault for whirlpoolTwo.
 * @param tokenVaultTwoB - PublicKey for the tokenB vault for whirlpoolTwo.
 * @param oracleOne - PublicKey for the oracle account for this whirlpoolOne.
 * @param oracleTwo - PublicKey for the oracle account for this whirlpoolTwo.
 * @param tokenAuthority - authority to withdraw tokens from the input token account
 * @param swapInput - Parameters in {@link TwoHopSwapInput}
 */
export declare type TwoHopSwapWithFeeDiscountParams = TwoHopSwapParams & {
    discountToken: PublicKey;
    whirlpoolDiscountInfoOne: PublicKey;
    whirlpoolDiscountInfoTwo: PublicKey;
    discountTokenOwnerAccount: PublicKey;
};
export declare function twoHopSwapWithFeeDiscountIx(program: Program<Whirlpool>, params: TwoHopSwapWithFeeDiscountParams): Instruction;
